import unittest
from spongebox.iobox import list_dir

class MyTestCase(unittest.TestCase):
    def test_something(self):
        print(list(list_dir(".")))
        self.assertEqual(True, True)

    def test_something1(self):
        print(list(list_dir(".",judge_func=lambda x:"test" in x)))
        self.assertEqual(True, True)

    def test_something2(self):
        print(list(list_dir(".",exp="\.py")))
        self.assertEqual(True, True)


if __name__ == '__main__':
    unittest.main()



import re


class judger:

    def __init__(self, suspect):
        self.suspect = suspect

    def isdigit(self):
        return False if re.match("^\d+\.\d+$|^\d+$", self.suspect) == None else True


# def filterlist_(lst, exp):
    # match = [re.search(exp, item) for item in lst]
    # return [item.group() for item in match if item is not None]


def filter_list(lst, pattern=None, judge_func=None):
    if pattern is not None:
        for item in lst:
            match_obj = re.search(pattern,item)
            if match_obj is not None:
                yield item
        return
    if judge_func is not None:
        for item in lst:
            if judge_func(item):
                yield item
        return
    raise TypeError("filter_list() missing arguments:either 'pattern' or 'judge_func' should be provided")


if __name__ == "__main__":
    print(list(filter_list(["aasdfs", "110dfadf"], "^\d+.*")))
    print(list(filter_list(["8899adf", "1109d09"], "^\d+.*")))
    print(list(filter_list(["eace", "123dfadf"], "^\d+.*")))
    print(list(filter_list(["eace", "123dfadf"])))
    print(judger("1.23").isdigit())
    print(judger("3").isdigit())



import unittest
from spongebox.rebox import filter_list


class MyTestCase(unittest.TestCase):
    def test_something(self):
        self.assertListEqual(list(filter_list(list("abc"), judge_func=lambda x: x == "a")), ["a"])

    def test_something1(self):
        self.assertListEqual(list(filter_list(list("abc"), pattern="a")), ["a"])


if __name__ == '__main__':
    unittest.main()



import os
from spongebox.timebox import stamp


class Tailor:
    def __init__(self, media_path, output_dir=None, suffix=None):
        self.media_path = media_path
        self.media_name = "".join(media_path.split("\\")[-1].split(".")[:-1])
        self.suffix = self.media_path.split(".")[-1] if suffix == None else suffix
        self.output_dir = "\\".join(media_path.split("\\")[:-1]) if output_dir == None else output_dir
        self.output = "{}\\{}_SUB.{}".format(self.output_dir, self.media_name, self.suffix)
        self.token = stamp()

    def cut(self, stamp: tuple, frag_idx: int, suffix=""):
        """
        :param stamp:(start_timestamp,end_timestamp) like ("000125","002334")
        :param frag_idx:idx for the cuted fragment,"0"
        :param suffix: 文件后缀，无需显示指定，一般从文件名获得
        :return:返回所截取片段的名称

        """
        start = str(stamp[0])
        end = str(stamp[1])
        start_timestamp = [int(start[i:i + 2]) for i in range(0, 5, 2)]
        end_timestamp = [int(end[i:i + 2]) for i in range(0, 5, 2)]
        print("fragment cut start:", start_timestamp, end_timestamp)

        suffix = self.media_path.split(".")[1] if suffix == "" else suffix
        # output_file = self.media_path.split(".")[0] + '_SUB' + str(frag_idx) + "." + suffix
        output_file = "{}\\{}_SUB{}.{}".format(self.output_dir, self.media_name, frag_idx, self.suffix)
        time_interval = end_timestamp[0] * 3600 + end_timestamp[1] * 60 + end_timestamp[2] - (
                start_timestamp[0] * 3600 + start_timestamp[1] * 60 + start_timestamp[2])
        cmd = "ffmpeg -ss {} -i {} -t {} -c:v copy -c:a copy {}".format(
            ":".join([start[i:i + 2] for i in range(0, 5, 2)]),
            self.media_path, time_interval,
            output_file)
        print(cmd)
        os.system(cmd)
        print("cut finished")
        return output_file.replace("\\", "\\\\")

    def concat(self, fragments):
        """
        :param fragments:["f:\\\\015203\download\\\\cnr_SUB0.mp4","f:\\\\download\\\\cnr_SUB1.mp4"]
        :return:
        """
        print("concat start:{}".format(fragments))
        media_list_path = "{}\\concat{}.txt".format(self.output_dir, self.token)
        concat_file_content = ["file " + input_file + "\n" for input_file in fragments]
        with open(media_list_path, mode="w") as f:
            f.writelines(concat_file_content)
        cmd = "ffmpeg -f concat -safe 0 -i {} -c copy {}".format(media_list_path, self.output)
        print(cmd)
        os.system(cmd)
        print("concat finished:{}".format(self.output))

    def launch(self, frag_stamp_list):
        def get_idx():
            i = 0
            while True:
                yield i
                i += 1

        fragments = list(map(self.cut, frag_stamp_list, get_idx()))
        if len(fragments) > 1:
            self.concat(fragments)



import unittest
from spongebox.iobox import mk_dir


class MyTestCase(unittest.TestCase):
    def test_something(self):
        mk_dir("C:\\Users\\LuoJi\\Desktop\\data1")
        mk_dir("C:\\Users\\LuoJi\\Desktop\\data2")
        self.assertEqual(True, False)  # add assertion here


if __name__ == '__main__':
    unittest.main()



import datetime
import time
import warnings
import re


class InvalidInputError(Exception):
    pass


class UnknownDateFormatError(InvalidInputError):
    pass


def crossbar(date):
    """
    :param date: yyyymmdd:int
    :return: yyyy-mm-dd:str
    """
    return "{}-{}-{}".format(str(date)[0:4], str(date)[4:6], str(date)[6:])


def format_match(date):
    """
    :param date:
    :return:
    """
    _ = str(date)
    if re.match(r"\d{8}$", _):
        return "%Y%m%d"
    elif re.match(r"\d{12}$", _):
        return "%Y%m%d%H%M"
    elif re.match(r"\d{14}$", _):
        return "%Y%m%d%H%M%S"
    elif re.match(r"\d{4}-\d{2}-\d{2}$", _):
        return "%Y-%m-%d"
    elif re.match(r"\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$", _):
        return "%Y-%m-%d %H:%M:%S"
    else:
        raise UnknownDateFormatError("valid formats: %Y%m%d, %Y%m%d%H%M, %Y%m%d%H%M%S, %Y-%m-%d, %Y-%m-%d %H:%M:%S")


def strptime(date):
    """
    :param date: formated str('yyyy-mm-dd','yyyymmdd','yyyy-mm-dd H:M:S'etc) or int(yyyymmdd,yyyymmddHMS)
    :param format:
    :return: datetime.datetime object
    """
    _ = str(date)
    return datetime.datetime.strptime(_, format_match(_))


def stamp():
    """
    :return: now() in "%Y%m%d%H%M%S":str
    """
    return datetime.datetime.now().strftime("%Y%m%d%H%M%S")


def interval(start, end):
    """
    :param start: %Y-%m-%d[.*]:str or yyyymmdd:int
    :param end: %Y-%m-%d[.*]:str or yyyymmdd:int
    :return:days:int between input dates
    """
    return (strptime(end) - strptime(start)).days


def move(date, days=0):
    """
    :param date: formated str('yyyy-mm-dd','yyyymmdd','yyyy-mm-dd H:M:S'etc) or int(yyyymmdd,yyyymmddHMS)
    :param days: int
    :return: datetime.datetime object
    """
    return strptime(date) + datetime.timedelta(days=days)


def add_days(date, n):
    """
    :param date: yyyy-mm-dd[.*]:str or yyyymmdd:int or datetime.datetime
    :param n: n days before/after date ( allow negative)
    :return: date before/after input date:datetime.datetime
    """
    warnings.warn("timebox.add_days() will be deprecated in futrue,use timebox.move() instead")
    date = str(date)
    if date.isdigit():
        date = crossbar(date)
    return datetime.datetime.strptime(date[0:10], "%Y-%m-%d") + datetime.timedelta(days=n)


def format(datetime, format="%Y-%m-%d %H:%m:%S"):
    """
    :param datetime: datetime.dateime
    :param format: default %Y-%m-%d %H:%m:%S
    :return: format time str
    """
    warnings.warn("timebox.format() will be deprecated in futrue,use timebox.strftime() instead")
    return datetime.strftime(format)


def timeit(func):
    def wrap(*args, **kwargs):
        ts = time.time()
        result = func(*args, **kwargs)
        te = time.time()
        # warnings.warn("this method will be deprecated in futrue,use measurebox.timeit instead")
        print("#{}() cost:{}".format(func.__name__, te - ts))
        return result

    return wrap


if __name__ == "__main__":
    print(strptime(20200302))
    print(strptime("20200302"))
    print(strptime("2020-03-02"))
    print(strptime("2020-03-02 15:20:02"))

    print(strftime(strptime("2020-03-02")))

    print(format(strptime("2020-03-02")))

    print(move(strptime("2020-03-02"), -28))

    print(stamp())
    print(interval("2020-01-16", "2020-01-17"))
    print(interval("2020-01-16", "2021-01-17"))
    print(add_days("2020-01-16", -1))
    # print(add_days("2020er33", -1))
    print(add_days(20200225, -1))


    @timeit
    def test():
        time.sleep(3)
        print("end")


    test()
    # print(format(datetime.datetime.now()))
    #
    #
    # @timeit
    # def test_timeit(n):
    #     a = 1
    #     for i in range(n):
    #         a += 1
    #     print(a)
    #
    #
    # test_timeit(100000)



import os
import pandas as pd
from spongebox.rebox import filter_list
import spongebox.timebox as timebox
import logging
import zipfile

pd.set_option('display.max_rows', 500)
pd.set_option('display.max_columns', 500)
pd.set_option('display.width', 1000)
pd.set_option('display.unicode.ambiguous_as_wide', True)
pd.set_option("display.unicode.east_asian_width", True)
pd.set_option("display.float_format", lambda x: "%.4f" % x)


class log:
    def __init__(self, output="console", log_file_path=None, mode="a", level=logging.DEBUG,
                 formatter=logging.Formatter(
                     '[%(asctime)s][%(thread)d][%(filename)s][line: %(lineno)d][%(levelname)s] ## %(message)s')):

        self.output = output
        self.log_file_path = log_file_path
        self.mode = mode
        self.level = level
        self.formatter = formatter

        # 创建一个logger
        self.logger = logging.getLogger('spongelogger{}'.format(timebox.stamp()))
        self.logger.setLevel(self.level)

        # 添加handler
        if self.output == "console":
            self._add_handler(logging.StreamHandler())
        elif self.output == "file":
            self._add_handler(logging.FileHandler(self.log_file_path, mode=self.mode))
        elif self.output == "both":
            self._add_handler(logging.StreamHandler())
            self._add_handler(logging.FileHandler(self.log_file_path))

    def _add_handler(self, logging_handler):
        logging_handler.setLevel(self.level)
        logging_handler.setFormatter(self.formatter)
        self.logger.addHandler(logging_handler)


def list_dir(dir_path, exp=None, judge_func=None):
    if exp is None and judge_func is None:
        return os.listdir(dir_path)
    else:
        return filter_list(os.listdir(dir_path), pattern=exp, judge_func=judge_func)


def mk_dir(path):
    if not os.path.exists(path):
        os.mkdir(path)


def read_overwrite(path, text_process_func, encoding="utf-8"):
    with open(path, "r+", encoding=encoding) as f:
        content = text_process_func(f.read())
        f.seek(0)
        f.truncate()
        f.write(content)


@timebox.timeit
def list_all_files(dir_path):
    lst = []
    for root, dir, flst in os.walk(dir_path):
        # print(root)
        # print(dir)
        # print(flst)
        lst.extend([root + "\\" + f for f in flst])
    return lst


def zip_dir(zip_name, dir_path):
    arch = dir_path.replace("\\", "/").split("/")[-1]
    with zipfile.ZipFile(zip_name, "w") as myzip:
        for fname in list_all_files(dir_path):
            print(fname)
            myzip.write(fname, fname.replace(dir_path, arch).replace("\\", "/"))


if __name__ == "__main__":
    mylog = log()
    mylog.logger.debug("haha")
# print(list_dir("../", exp=".*md$"))
# lst = []
# lst1=[]
# print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test",lst))
# print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test",lst1))
# print(walk_all_files("C:\\Users\\LuoJi\\Downloads\\test"))
# list_all_files("C:\\Users\\LuoJi\\Documents\\05照片")
# print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test"))



import unittest
from spongebox.timebox import *

class MyTestCase(unittest.TestCase):
    def test_case1(self):
        self.assertEqual(format_match(20200302), "%Y%m%d")

    def test_case2(self):
        self.assertEqual(format_match("20200302"), "%Y%m%d")

    def test_case3(self):
        self.assertEqual(format_match("2020-03-02"), "%Y-%m-%d")

    def test_case4(self):
        self.assertEqual(format_match("2020-03-02 15:20:02"), "%Y-%m-%d %H:%M:%S")

    def test_case5(self):
        self.assertRaises(UnknownDateFormatError, format_match, "202502-36 15:20:02")

    def test_case6(self):
        self.assertEqual(format_match("202009121546"), "%Y%m%d%H%M")

    def test_case7(self):
        self.assertEqual(format_match("20200912154634"), "%Y%m%d%H%M%S")

if __name__ == '__main__':
    unittest.main()



import unittest
from spongebox.iobox import zip_dir,list_all_files
import os


class MyTestCase(unittest.TestCase):
    def test_something(self):
        # zip_dir("E:\\download\\haha.zip", "E:\\download\\test")
        self.assertEqual(True, True)

    def test_something1(self):
        print(os.getcwd())
        print(list_all_files("testzip"))
        zip_dir("E:\\download\\momo.zip", "testzip")
        self.assertEqual(True, True)


if __name__ == '__main__':
    unittest.main()



import spongebox.structbox as structbox
import re


class chinesemonetary:

    def __init__(self, min_unit="fen"):
        self.min_unit = "fen"

    def decompose_amount(self, cn_amount):
        if len(cn_amount) <= 1:
            return cn_amount
        # print(cn_amount)
        pattern = "(?P<yi>.*亿)*(?P<wan>.*万)*(?P<qian>.*[千仟])*(?P<bai>.*[百佰])*(?P<shi>.*[十拾])*(?P<yuan>.*[元圆块])*"
        grp_keys = ["yi", "wan", "qian", "bai", "shi", "yuan"]
        units = ["亿", "万", "仟千", "佰百", "拾十", "元圆块"]
        if self.min_unit == "fen":
            pattern += "(?P<jiao>.*[角毛])*(?P<fen>.*分)*"
            grp_keys.extend(["jiao", "fen"])
            units.extend(["角毛", "分"])
        elif self.min_unit == "yuan":
            pass
        else:
            raise Exception("min unit should be:yuan or fen")
        pattern += "(?P<tbd>.*)"
        grp_keys.append("tbd")

        _ = re.search(pattern, cn_amount)
        ret = [_.group(k) for k in grp_keys]
        # print(ret)

        only_tbd = True
        for p in ret[:-1]:
            if p != None:
                only_tbd = False
                break
        if only_tbd:
            return list(ret[-1] + "零零")

        ret = [amt if amt != None else "" for amt in ret]
        print(ret)

        def switch(i, stop):
            if ret[i - 1] == "" and i > stop:
                ret[i - 1], ret[i] = ret[i], ret[i - 1]
                switch(i - 1, stop)
            else:
                pass

        if ret[-1] != "":
            stop = 0 - len(ret)
            if "零" in ret[-1]:
                if self.min_unit == "fen":
                    stop = -4
                else:
                    stop = -2
            switch(-1, stop)

        self.min_unit = "yuan"

        # print(units)
        for i in range(0, len(ret) - 1):
            for unit in units[i]:
                ret[i] = ret[i].replace(unit, "")
        ret = [x.lstrip("零") for x in ret]
        ret = [x if x != "" else "零" for x in ret]
        ret[1] = self.decompose_amount(ret[1])[-4:]
        # ret = flatten_list(ret)
        ret[0] = self.decompose_amount(ret[0])
        ret = [x if x != "" else "零" for x in ret]
        print(ret[:-1])
        print()
        return ret[:-1]

    def digitalize_chinese_moneytary(self, cn_amount):
        print(cn_amount)
        if cn_amount == "":
            return -1
        cn_num = {'零': 0, '壹': 1, '贰': 2, '叁': 3, '肆': 4, '伍': 5, '陆': 6, '柒': 7, '捌': 8,
                  '玖': 9, '一': 1, '二': 2, '三': 3, '四': 4, '五': 5, '六': 6, '七': 7, '八': 8, '九': 9, '两': 2}
        ret = ""
        _ = ""
        if len(cn_amount) == 1:
            _ = cn_amount + "零零"
        else:
            _ = self.decompose_amount(cn_amount)
            _ = "".join(structbox.flatten_list(_))
        for n in _:
            ret += str(cn_num[n])
        ret = int(ret)
        print(ret)
        print()
        return ret


if __name__ == "__main__":
    _ = []

    _.append(chinesemonetary().digitalize_chinese_moneytary("玖仟捌佰柒拾陆万伍仟肆佰叁拾贰亿壹仟零玖拾捌万柒仟陆佰伍拾肆元叁角贰分") == 987654321098765432)
    _.append(chinesemonetary().digitalize_chinese_moneytary("柒仟陆佰伍拾肆元叁角贰分") == 765432)
    _.append(chinesemonetary().digitalize_chinese_moneytary("柒仟陆佰伍拾肆元贰分") == 765402)
    _.append(chinesemonetary().digitalize_chinese_moneytary("一千零四") == 100400)
    _.append(chinesemonetary().digitalize_chinese_moneytary("一千零四拾") == 104000)
    _.append(chinesemonetary().digitalize_chinese_moneytary("一千零四拾五") == 104500)
    _.append(chinesemonetary().digitalize_chinese_moneytary("一块两毛二") == 122)
    _.append(chinesemonetary().digitalize_chinese_moneytary("三百四") == 34000)
    _.append(chinesemonetary().digitalize_chinese_moneytary("三百零四") == 30400)
    _.append(chinesemonetary().digitalize_chinese_moneytary("三百零四块") == 30400)
    _.append(chinesemonetary().digitalize_chinese_moneytary("三千叁佰万") == 3300000000)
    _.append(chinesemonetary().digitalize_chinese_moneytary("二十") == 2000)
    _.append(chinesemonetary().digitalize_chinese_moneytary("一块二") == 120)
    _.append(chinesemonetary().digitalize_chinese_moneytary("三毛一") == 31)
    _.append(chinesemonetary().digitalize_chinese_moneytary("三块") == 300)
    _.append(chinesemonetary().digitalize_chinese_moneytary("三百") == 30000)
    _.append(chinesemonetary().digitalize_chinese_moneytary("三") == 300)
    _.append(chinesemonetary().digitalize_chinese_moneytary("壹二三") == 12300)
    _.append(chinesemonetary().digitalize_chinese_moneytary("九八三四") == 983400)
    _.append(chinesemonetary().digitalize_chinese_moneytary("肆万") == 4000000)
    _.append(chinesemonetary().digitalize_chinese_moneytary("肆万二") == 4200000)

    print(_)



def repay_plan_factory(repay_type):
    if repay_type == "等额本息":
        return gen_repay_plan_fixed_prin_int
    elif repay_type == "等额本金":
        return gen_repay_plan_fixed_prin
    elif repay_type == "等本等息":
        return gen_repay_plan_fixed_prin_fixed_int
    else:
        return None


def gen_repay_plan_fixed_prin_int(principal, monthly_rate, n_periods):
    prin_remain = principal
    plan = []
    repay_per_month = principal * monthly_rate * (1 + monthly_rate) ** n_periods / ((1 + monthly_rate) ** n_periods - 1)
    for i in range(0, n_periods):
        cur_int = round(prin_remain * monthly_rate, 2)
        cur_prin = round(repay_per_month - cur_int, 2)
        prin_remain -= cur_prin
        plan.append([cur_prin, cur_int])
    plan[-1][0] = round(principal - sum([_[0] for _ in plan])+plan[-1][0],2)
    plan[-1][1] = round(repay_per_month - plan[-1][0], 2)
    return plan


def gen_repay_plan_fixed_prin(principal, monthly_rate, n_periods):
    prin_remain = principal
    plan = []
    prin_per_month = round(principal / n_periods, 2)
    for i in range(0, n_periods):
        _ = prin_remain * monthly_rate
        prin_remain -= prin_per_month
        plan.append([prin_per_month, round(_, 2)])
    plan[-1][0] = round(principal - sum([_[0] for _ in plan]) + plan[-1][0], 2)
    return plan


def gen_repay_plan_fixed_prin_fixed_int(principal, monthly_rate, n_periods):
    plan = []
    for i in range(0, n_periods):
        plan.append([round(principal / n_periods, 2), round(principal * monthly_rate, 2)])
    plan[-1][0] = round(principal - sum([_[0] for _ in plan]) + plan[-1][0], 2)
    return plan



import unittest
from spongebox.structbox import flatten_list

class MyTestCase(unittest.TestCase):
    def test_something0(self):
        self.assertListEqual(flatten_list([1,[2,3,[4,5],6],7]), [i for i in range(1,8)])


if __name__ == '__main__':
    unittest.main()



import unittest
from spongebox.financebox.loanbox import repay_plan_factory


class MyTestCase(unittest.TestCase):
    def setUp(self) -> None:
        self.prin = 10000
        self.mon_rate = 0.01
        self.n_periods = 3

    def test_something0(self):
        _ = (repay_plan_factory("等额本息"))(self.prin,self.mon_rate,self.n_periods)
        print(_)
        # self.assertEqual(True, False)
        # self.assertListEqual()

    def test_something1(self):
        _ = (repay_plan_factory("等额本金"))(self.prin, self.mon_rate, self.n_periods)
        print(_)
        # self.assertListEqual()

    def test_something2(self):
        _ = (repay_plan_factory("等本等息"))(self.prin, self.mon_rate, self.n_periods)
        print(_)
        # self.assertListEqual()

if __name__ == '__main__':
    unittest.main()



import matplotlib.pyplot as plt
import seaborn as sns
import pandas as pd
import numpy as np

# 支持中文
plt.rcParams['font.sans-serif'] = ['SimHei']  # 用来正常显示中文标签
plt.rcParams['axes.unicode_minus'] = False  # 用来正常显示负号
sns.set(font='SimHei')  # 解决Seaborn中文显示问题


def autolabel(rects):
    for rect in rects:
        height = rect.get_height()
        plt.text(rect.get_x() + rect.get_width() / 2. -
                 0.2, 1.03 * height, '%s' % float(height))


def countplot(x, data, hue=None, prop=False, sort_by="count", ascending=False):
    _ = data.fillna("").groupby(x).count().reset_index()
    # print(_.head(1))
    _.rename(columns={_.columns[1]: "count"}, inplace=True)
    if sort_by != None:
        _.sort_values(sort_by, ascending=ascending, inplace=True)
        _.reset_index(inplace=True, drop=True)
    # print(_.head(1))
    total = _.iloc[:, 1].sum() * 1.0
    _["display"] = _.iloc[:, 1]
    if prop:
        _["display"] = _.iloc[:, 1].apply(
            lambda x: str(int(round(x / total * 100))) + "%")
    # add fake col to normalize the bar's sequences
    _[" "+x+" "] = _[x].apply(lambda x:""+str(x))
    g = sns.barplot(x=" "+x+" ", y=_.columns[1], data=_, hue=hue)
    # 在柱状图的上面显示各个类别的数量
    for index, row in _.iterrows():
        # 在柱状图上绘制该类别的数量
        g.text(row.name, row[1], row.display, color="black", ha="center")


if __name__ == "__main__":
    # l1 = [68, 96, 85, 86, 76, 87, 95]
    # l2 = [85, 68, 79, 89, 94, 82, 90]
    #
    # name = ['A', 'B', 'C', 'D', 'E', 'F', 'E']
    # total_width, n = 0.8, 2
    # width = total_width / n
    # x = [0, 1, 2, 3, 4, 5, 6]
    #
    # a = plt.bar(x, l1, width=width, label='数学', fc='y')
    # for i in range(len(x)):
    #     x[i] = x[i] + width
    # b = plt.bar(x, l2, width=width, label='语文', tick_label=name, fc='r')
    #
    # print(type(b))
    #
    # autolabel(a)
    # autolabel(b)
    #
    # plt.xlabel('学生')
    # plt.ylabel('成绩')
    # plt.title('学生成绩')
    # plt.legend()
    # plt.show()

    # def classify(x):
    #     if x == 0:
    #         return "差"
    #     elif x == 1:
    #         return "中"
    #     else:
    #         return "好"
    #
    #
    # def subject(x):
    #     if x == 0:
    #         return "文科"
    #     else:
    #         return "理科"
    #
    #
    # df = pd.DataFrame(np.random.randint(0, 3, (10, 2)), columns="语文,数学".split(","))
    # df["语文"] = df["语文"].apply(lambda x: classify(x))
    # df["数学"] = df["数学"].apply(lambda x: classify(x))
    # df["分科"] = df["语文"].apply(lambda x: subject(np.random.randint(0, 2)))
    # print(df)
    #
    # plt.subplot(1, 2, 1)
    # sns.countplot(x="语文", data=df)
    # plt.subplot(1, 2, 2)
    # sns.countplot(x="语文", hue="分科", data=df)
    # plt.show()
    #
    # countplot(x="语文", data=df, prop=True)
    # plt.show()
    #
    # sns.countplot(x="语文", hue="分科", data=df)
    # plt.show()

    df = pd.DataFrame(np.random.randint(0,10,(10,3)),columns=list("abc"))
    countplot("a",df)
    plt.show()



import unittest
from spongebox.mediabox import Tailor

frgs = []
frgs.append(("000000", "010438"))
# frgs.append(("000106", "000136"))
# Tailor("F:\\download\\20\\vedio.mp4").launch(frgs)
# Tailor("F:\\download\\20\\FCDC-123.mp4",output_dir="F:\\download\\20").launch(frgs)
Tailor("C:\\Users\\LuoJi\\Desktop\\HJMO-457.mp4",output_dir="C:\\Users\\LuoJi\\Desktop").launch(frgs)


import unittest
from spongebox.iobox import read_overwrite
import os


class MyTestCase(unittest.TestCase):
    def test_something(self):
        print(os.getcwd())
        read_overwrite("test.txt",lambda x:"haha")
        self.assertEqual(True, True)


if __name__ == '__main__':
    unittest.main()
